@@ -1,20 +1,26 @@
 `slope` <-
-function(ogg, conf.level=0.95){
-#2/10/03; 21/10/03; 4/11/03; 24/02/04; 25/02/04; 28/04/06
+function(ogg, parm, conf.level=0.95, rev.sgn=FALSE){
 #Ad ogni chiamata di grep()  stato aggiunto l'argomento extended=F per consentire Z=log(x)
-#returns Est., St.Err., t value and Conf Interv (1-level) for the slopes
-#      of the variables having a segmented relationship in the model.
-#ogg: a segmented object returned by segmented().
         if(!"segmented"%in%class(ogg)) stop("A segmented model is needed")
         nomepsi<-rownames(ogg$psi) #OK
         nomeU<-ogg$nameUV[[1]]
         nomeZ<-ogg$nameUV[[3]]
+        if(missing(parm)) {
+          nomeZ<- ogg$nameUV[[3]]
+          if(length(rev.sgn)==1) rev.sgn<-rep(rev.sgn,length(nomeZ))
+          }
+             else {
+                if(! all(parm %in% ogg$nameUV[[3]])) {stop("invalid parm")}
+                  else {nomeZ<-parm}
+                  }
+        if(length(rev.sgn)!=length(nomeZ)) rev.sgn<-rep(rev.sgn, length.out=length(nomeZ))
         nomi<-names(coef(ogg))
         nomi<-nomi[-match(nomepsi,nomi)] #escludi i coef delle V
         index<-vector(mode = "list", length = length(nomeZ))
         for(i in 1:length(nomeZ)) index[[i]]<-grep(nomeZ[i], nomi, extended=FALSE) 
         Ris<-list()   
         digits <- max(3, getOption("digits") - 3)
+        rev.sgn<-rep(rev.sgn, length.out=length(nomeZ))
         for(i in 1:length(index)){
             ind<-unlist(index[[i]])
             M<-matrix(1,length(ind),length(ind))
@@ -30,9 +36,14 @@ function(ogg, conf.level=0.95){
             #se la left slope  nulla....
             if(identical(length(ind),length(grep(nomeZ[i], nomeU, extended=FALSE)))){
                     ris<-rbind(c(0,rep(NA,(ncol(ris)-1))),ris)}
+            if(rev.sgn[i]){
+                ris<-cbind(-ris[nrow(ris):1,1],ris[nrow(ris):1,2],-ris[nrow(ris):1,3],
+                      -ris[nrow(ris):1,5],-ris[nrow(ris):1,4])}
             dimnames(ris)<-list(paste("slope", 1:nrow(ris), sep=""),c("Est.","St.Err.","t value",cin[1],cin[2]))
             Ris[[nomeZ[i]]]<-signif(ris,digits)
-                }
+                } #end loop i
+            #if(!missing(parm)){
+            #    if(!all(parm %in% ogg$nameUV[[3]])) stop("invalid parm") else Ris<-Ris[parm]}
             Ris
             }
 
